from typing import List

from .package import ArgosPackage

class ITranslator():
    def translate(text: str) -> str:
        raise NotImplementedError()

    def translate_batch(batch: List[str]) -> List[str]:
        raise NotImplementedError()
    


class TranslationError(Exception):
    """Custom exception for translation-related errors."""
    pass


class InitializationError(Exception):
    """Custom exception for initialization errors."""
    pass


class ValidationError(Exception):
    """Custom exception for validation errors."""
    pass
